# FORWARD4-ALERTs

A CLI app used to stimulate a forum for fake job alerts


### How to install 


Verify that you have the following prerequisites in place before installing the sample:

1. Install Python from https://www.python.org/. The program can be run on any operating system that supports Python 3.x, including recent versions of Windows, Linux, and Mac OS. In some cases, you may need to use a different command to launch Python. 

Follow these steps to install the sample code on your computer:

Clone the repo with this command:

`git clone https://github.com/startng/forward4_alerts.git`   

Create and activate a virtual environment (optional). 

In the root folder of your cloned repo, install the dependencies for the sample as listed in the requirements.txt file with this command: pip install -r requirements.txt.



### How to use
Follow these steps to run the sample app:
1. Go into the root directory of the repo

2. Then run the following command on the terminal   
    `python runs.py`


